package edu.westga;

import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.util.HashMap;
import java.util.Map;

import twitter4j.Status;

import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.util.Log;

/**
 * Class that holds username and image inside a Hashmap
 * 
 * @author Gregory Oliver
 * @version 2011.04.25
 */
public class ImageSafe {
	private final Map<String, Bitmap> images;

	public ImageSafe() {
		this.images = new HashMap<String, Bitmap>();
	}

	/**
	 * This method returns the bitmap value of the username key
	 * 
	 * @param status
	 * @return
	 */
	public Bitmap getImageFor(Status status) {
		String screenName = status.getUser().getScreenName();

		if (!this.images.containsKey(screenName)) {
			URL url = status.getUser().getProfileImageURL();
			try {
				Bitmap bmp = this.makeBitmap(url);
				this.images.put(screenName, bmp);
			} catch (IOException e) {
				Log.i(ImageSafe.class.getName(),
						"error fetching profile image for " + screenName, e);

				this.images.put(screenName, null);
			}
		}

		return (Bitmap) this.images.get(screenName);

	}

	/**
	 * This method parses the URL object into a Bitmap object
	 * 
	 * @param url
	 * @return Bitmap
	 * @throws IOException
	 */
	private Bitmap makeBitmap(URL url) throws IOException {

		InputStream stream;
		stream = url.openStream();
		Bitmap bmp = BitmapFactory.decodeStream(stream);
		stream.close();

		return bmp;
	}

}
