package edu.westga;
import java.io.IOException;
import java.net.URL;
import java.util.List;

import twitter4j.ResponseList;
import twitter4j.Status;
import twitter4j.TwitterException;
import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.preference.PreferenceActivity;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.BaseAdapter;
import android.widget.ImageView;
import android.widget.ListAdapter;
import android.widget.TextView;
import edu.westga.model.tweetAggregator.TweetAggregator;

/**
 * Factory to create a list adapter for the Twitter list view.
 * 
 * @author Daniel J. Rocco
 * @version 2011.04.21
 */
public class ListAdapterFactory {
	private static class TweetListAdapter extends BaseAdapter {
		private List<Status> posts;
		private Context mContext;
		private ImageSafe imagemap;
		private int x;
		private int lightBlue;

		/**
		 * Creats a new TweetListAdapter and sets its properties
		 * @param context
		 * 			-	The Android Context to use
		 * @param posts
		 * 			-	The List of statuses to be displayed
		 */
		public TweetListAdapter(Context context, ResponseList<Status> posts) {
			this.mContext = context;
			this.posts = posts;
			this.imagemap = new ImageSafe();
			this.x = 2;
			this.lightBlue = 0xFF5DB9FB;
			
		}

		@Override
		public int getCount() {
			return posts.size();
		}

		@Override
		public Object getItem(int position) {
			return posts.get(position);
		}

		@Override
		public long getItemId(int position) {
			return position;
		}

		@Override
		public View getView(int position, View convertView, ViewGroup parent) {
			View item;
			ImageView image = null;
			item = LayoutInflater.from(mContext).inflate(R.layout.tweet,
					parent, false);
			
			TextView text = (TextView) item.findViewById(R.id.textView);
			
			Status status = posts.get(position);
			String post = String.format("@%s %tb %<te - %s", status.getUser()
					.getScreenName(), status.getCreatedAt(), status.getText());

			text.setText(post);
			
			Bitmap icon = this.imagemap.getImageFor(status);
			if (icon != null) {
				//Sets imageview image to bitmap value of the screenName
				image = (ImageView) item.findViewById(R.id.imageView);
				image.setImageBitmap(icon);
			}
			
			if(x % 2 !=0){
				
				text.setBackgroundColor(lightBlue);
				image.setBackgroundColor(lightBlue);
			}
				x += 1;
				
			return item;
		}

	}

	/**
	 * Creation method to build a new ListAdapter from a Twitter query.
	 * 
	 * Returns a one-element, "no events found" adapter if there was a problem
	 * with the query.
	 * 
	 * @param context
	 *            the application Activity context
	 * @return a ListAdapter for a list of Tweets. If the Twitter query fails,
	 *         returns an adapter to a single string indicating that no events
	 *         were found
	 */
	public static ListAdapter getListAdapter(Context context) {
		try {
			TweetAggregator aggregator = new TweetAggregator();
			ResponseList<Status> posts = aggregator.getFriendsTimeline();
			

			return new TweetListAdapter(context, posts);
		} catch (TwitterException e) {
			Log.i(ListAdapterFactory.class.getName(), "error fetching tweets",
					e);
		}

		return new ArrayAdapter<String>(context,
				android.R.layout.simple_list_item_1,
				new String[] { "No events found..." });
	}
}
